@@ -39,7 +39,8 @@ class BehaviorChangeWarning(UserWarning):
 
 try:
     import numpy as np
-    from numpy import ndarray, datetime64 as np_datetime64
+    from numpy import datetime64 as np_datetime64
+    from numpy import ndarray
 
     HAS_NUMPY = True
     NUMPY_VER = np.__version__
@@ -157,6 +158,14 @@ try:
 except ImportError:
     pass
 
+try:
+    from dask import array as dask_array
+    from dask.base import compute, persist, visualize
+
+except ImportError:
+    compute, persist, visualize = None, None, None
+    dask_array = None
+
 
 def is_upcast_type(other) -> bool:
     """Check if the type object is a upcast type using preset list.
@@ -212,7 +221,7 @@ def eq(lhs, rhs, check_all: bool):
     bool or array_like of bool
     """
     out = lhs == rhs
-    if check_all and isinstance(out, ndarray):
+    if check_all and is_duck_array_type(type(out)):
         return out.all()
     return out
 
