@@ -693,6 +693,13 @@ class TestIssues(QuantityTestCase):
         assert isinstance(q1, ureg.Quantity)
         assert len(q0) == len(q1) == 0
 
+    def test_issue1058(self):
+        """ verify that auto-reducing quantities with three or more units
+        of same base type succeeds """
+        q = 1 * ureg.mg / ureg.g / ureg.kg
+        q.ito_reduced_units()
+        self.assertIsInstance(q, ureg.Quantity)
+
     def test_issue1062_issue1097(self):
         # Must not be used by any other tests
         assert "nanometer" not in ureg._units
@@ -738,6 +745,13 @@ class TestIssues(QuantityTestCase):
         ureg.enable_contexts("c2")
         ureg.enable_contexts("c3")
 
+    @helpers.requires_numpy()
+    def test_issue_1136(self):
+        assert (2 ** ureg.Quantity([2, 3], "") == 2 ** np.array([2, 3])).all()
+
+        with pytest.raises(DimensionalityError):
+            2 ** ureg.Quantity([2, 3], "m")
+
 
 if np is not None:
 
